@@ -49,6 +49,11 @@ class TestAzAz:
             assert iban[:2] == AzAzBankProvider.country_code
             assert re.fullmatch(r"\d{2}[A-Z]{4}\d{20}", iban[2:])
 
+    def test_bank(self, faker, num_samples):
+        for _ in range(num_samples):
+            bank = faker.bank()
+            assert bank in AzAzBankProvider.banks
+
 
 class TestNoNo:
     """Test no_NO bank provider"""
